.. SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.config:

================
 Config Modules
================

An exhaustive listing of all available preset configuration modules shipped
with this package.

.. autosummary::
   :toctree: api
   :recursive:
   :template: mednet/configmodule.rst

   mednet.config
